# genwiki2024
Semantification of Genealogy

[![pypi](https://img.shields.io/pypi/pyversions/genwiki2024)](https://pypi.org/project/genwiki2024/)
[![Github Actions Build](https://github.com/WolfgangFahl/genwiki2024/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/genwiki2024/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/genwiki2024.svg)](https://pypi.python.org/pypi/genwiki2024/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/genwiki2024.svg)](https://github.com/WolfgangFahl/genwiki2024/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/genwiki2024.svg)](https://github.com/WolfgangFahl/genwiki2024/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/genwiki2024/)
[![License](https://img.shields.io/github/license/WolfgangFahl/genwiki2024.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Demo/Simulation
[Demo](http://genwiki2024.bitplan.com/)
